@@ -247,10 +247,9 @@ module Hledger.Cli.Commands.Balance (
  ,multiBalanceReportHtmlRows
  ,balanceReportAsTable
  ,balanceReportTableAsText
- ,tests_Hledger_Cli_Commands_Balance
+ ,tests_Balance
 ) where
 
-import Control.Monad (when)
 import Data.List
 import Data.Maybe
 --import qualified Data.Map as Map
@@ -258,8 +257,6 @@ import qualified Data.Text as T
 import qualified Data.Text.Lazy as TL
 import System.Console.CmdArgs.Explicit as C
 import Lucid as L
-import Text.CSV
-import Test.HUnit
 import Text.Printf (printf)
 import Text.Tabular as T
 --import Text.Tabular.AsciiWide
@@ -267,6 +264,7 @@ import Text.Tabular as T
 import Hledger
 import Hledger.Cli.CliOptions
 import Hledger.Cli.Utils
+import Hledger.Read.CsvReader (CSV, printCSV)
 
 
 -- | Command line options for this command.
@@ -314,7 +312,6 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts} j = do
       case (budget, interval) of
         (True, _) -> do
           -- single or multicolumn budget report
-          when (sort_amount_ ropts) $ error' "Sorry, --sort-amount is not yet supported with --budget."  -- TODO
           reportspan <- reportSpan j ropts
           let budgetreport     = dbg1 "budgetreport"     $ budgetReport ropts assrt showunbudgeted reportspan d j
                 where
@@ -395,21 +392,6 @@ balanceReportAsText opts ((items, total)) = unlines $ concat lines ++ t
                 in overline : totallines
                Left _ -> []
 
-tests_balanceReportAsText = [
-  "balanceReportAsText" ~: do
-  -- "unicode in balance layout" ~: do
-    j <- readJournal'
-      "2009/01/01 * медвежья шкура\n  расходы:покупки  100\n  актив:наличные\n"
-    let opts = defreportopts
-    balanceReportAsText opts (balanceReport opts (queryFromOpts (parsedate "2008/11/26") opts) j) `is`
-      unlines
-      ["                -100  актив:наличные"
-      ,"                 100  расходы:покупки"
-      ,"--------------------"
-      ,"                   0"
-      ]
- ]
-
 {-
 :r
 This implementation turned out to be a bit convoluted but implements the following algorithm for formatting:
@@ -646,5 +628,19 @@ balanceReportTableAsText ropts = tableAsText ropts showamt
             | otherwise    =  showMixedAmountOneLineWithoutPrice
 
 
-tests_Hledger_Cli_Commands_Balance = TestList
-  tests_balanceReportAsText
+tests_Balance = tests "Balance" [
+
+   tests "balanceReportAsText" [
+    test "unicode in balance layout" $ do
+      j <- io $ readJournal' "2009/01/01 * медвежья шкура\n  расходы:покупки  100\n  актив:наличные\n"
+      let opts = defreportopts
+      balanceReportAsText opts (balanceReport opts (queryFromOpts (parsedate "2008/11/26") opts) j) `is`
+        unlines
+        ["                -100  актив:наличные"
+        ,"                 100  расходы:покупки"
+        ,"--------------------"
+        ,"                   0"
+        ]
+  ]
+
+ ]
