@@ -11,15 +11,13 @@ module Hledger.Cli.Commands.Print (
  ,print'
  -- ,entriesReportAsText
  ,originalTransaction
- ,tests_Hledger_Cli_Commands_Print
 )
 where
 
 import Data.Text (Text)
 import qualified Data.Text as T
 import System.Console.CmdArgs.Explicit
-import Test.HUnit
-import Text.CSV
+import Hledger.Read.CsvReader (CSV, printCSV)
 
 import Hledger
 import Hledger.Cli.CliOptions
@@ -67,8 +65,8 @@ printEntries opts@CliOpts{reportopts_=ropts} j = do
 entriesReportAsText :: CliOpts -> EntriesReport -> String
 entriesReportAsText opts = concatMap (showTransactionUnelided . gettxn) 
   where
-    gettxn | useexplicittxn = id                   -- use the fully inferred/explicit txn
-           | otherwise      = originalTransaction  -- use the original as-written txn, more or less
+    gettxn | useexplicittxn = id                   -- use fully inferred amounts & txn prices 
+           | otherwise      = originalTransaction  -- use original as-written amounts/txn prices
     -- Original vs inferred transactions/postings were causing problems here, disabling -B (#551).
     -- Use the explicit one if -B or -x are active.
     -- This passes tests; does it also mean -B sometimes shows missing amounts unnecessarily ?  
@@ -181,8 +179,3 @@ printMatch CliOpts{reportopts_=ropts} j desc = do
       | otherwise           = Just $ snd $ head historymatches
       where
         historymatches = transactionsSimilarTo j q desc
-
--- tests
-
-tests_Hledger_Cli_Commands_Print = TestList []
-  -- tests_showTransactions
