@@ -10,6 +10,7 @@ where
 #if !(MIN_VERSION_base(4,11,0))
 import Control.Monad.Writer
 #endif
+import Data.Functor.Identity
 import Data.List (sortOn, foldl')
 import Data.String.Here
 import qualified Data.Text as T
@@ -23,7 +24,8 @@ import qualified Data.Algorithm.Diff as D
 
 rewritemode = hledgerCommandMode
   [here| rewrite
-Print all transactions, adding custom postings to the matched ones.
+Print all transactions, rewriting the postings of matched transactions.
+For now the only rewrite available is adding new postings, like print --auto.
 
 FLAGS
 
@@ -146,6 +148,20 @@ See also:
 
 https://github.com/simonmichael/hledger/issues/99
 
+#### rewrite vs. print --auto
+
+This command predates print --auto, and currently does much the same thing,
+but with these differences:
+
+- with multiple files, rewrite lets rules in any file affect all other files.
+  print --auto uses standard directive scoping; rules affect only child files.
+
+- rewrite's query limits which transactions can be rewritten; all are printed.
+  print --auto's query limits which transactions are printed.
+
+- rewrite applies rules specified on command line or in the journal.
+  print --auto applies rules specified in the journal.
+
   |]
   [flagReq ["add-posting"] (\s opts -> Right $ setopt "add-posting" s opts) "'ACCT  AMTEXPR'"
            "add a posting to ACCT, which may be parenthesised. AMTEXPR is either a literal amount, or *N which means the transaction's first matched amount multiplied by N (a decimal number). Two spaces separate ACCT and AMTEXPR."
@@ -161,33 +177,29 @@ https://github.com/simonmichael/hledger/issues/99
 -- TODO allow using this on unbalanced entries, eg to rewrite while editing
 
 rewrite opts@CliOpts{rawopts_=rawopts,reportopts_=ropts} j@Journal{jtxns=ts} = do 
-  d <- getCurrentDay
-  let q = queryFromOpts d ropts
-  modifier <- modifierTransactionFromOpts rawopts
   -- create re-writer
-  let modifiers = modifier : jmodifiertxns j
-      -- Note that some query matches require transaction. Thus modifiers
-      -- pipeline should include txnTieKnot on every step.
-      modifier' = foldr (flip (.) . fmap txnTieKnot . runModifierTransaction q) id modifiers
+  let modifiers = transactionModifierFromOpts opts : jtxnmodifiers j
+      applyallmodifiers = foldr (flip (.) . transactionModifierToFunction) id modifiers
   -- rewrite matched transactions
-  let j' = j{jtxns=map modifier' ts}
-  -- run the print command, showing all transactions
-  outputFromOpts rawopts opts{reportopts_=ropts{query_=""}} j j'
+  let j' = j{jtxns=map applyallmodifiers ts}
+  -- run the print command, showing all transactions, or show diffs
+  printOrDiff rawopts opts{reportopts_=ropts{query_=""}} j j'
 
-postingp' :: T.Text -> IO Posting
-postingp' t = runJournalParser (postingp Nothing <* eof) t' >>= \case
-        Left err -> fail $ parseErrorPretty' t' err
-        Right p -> return p
-    where t' = " " <> t <> "\n" -- inject space and newline for proper parsing
+-- | Build a 'TransactionModifier' from any query arguments and --add-posting flags
+-- provided on the command line, or throw a parse error.
+transactionModifierFromOpts :: CliOpts -> TransactionModifier
+transactionModifierFromOpts CliOpts{rawopts_=rawopts,reportopts_=ropts} = 
+  TransactionModifier{tmquerytxt=q, tmpostingrules=ps}
+  where
+    q = T.pack $ query_ ropts
+    ps = map (parseposting . stripquotes . T.pack) $ listofstringopt "add-posting" rawopts
+    parseposting t = either (error' . errorBundlePretty) id ep
+      where
+        ep = runIdentity (runJournalParser (postingp Nothing <* eof) t')
+        t' = " " <> t <> "\n" -- inject space and newline for proper parsing
 
-modifierTransactionFromOpts :: RawOpts -> IO ModifierTransaction
-modifierTransactionFromOpts opts = do
-    postings <- mapM (postingp' . stripquotes . T.pack) $ listofstringopt "add-posting" opts
-    return
-        ModifierTransaction { mtvalueexpr = T.empty, mtpostings = postings }
-
-outputFromOpts :: RawOpts -> (CliOpts -> Journal -> Journal -> IO ())
-outputFromOpts opts
+printOrDiff :: RawOpts -> (CliOpts -> Journal -> Journal -> IO ())
+printOrDiff opts
     | boolopt "diff" opts = const diffOutput
     | otherwise = flip (const print')
 
@@ -198,8 +210,7 @@ diffOutput j j' = do
 
 type Chunk = (GenericSourcePos, [DiffLine String])
 
--- | Render list of changed lines as a unified diff
---
+-- XXX doctests, update needed:
 -- >>> putStr $ renderPatch [(GenericSourcePos "a" 1 1, [D.First "x", D.Second "y"])]
 -- --- a
 -- +++ a
@@ -224,6 +235,7 @@ type Chunk = (GenericSourcePos, [DiffLine String])
 -- +++ b
 -- @@ -5,0 +5,1 @@
 -- +z
+-- | Render list of changed lines as a unified diff
 renderPatch :: [Chunk] -> String
 renderPatch = go Nothing . sortOn fst where
     go _ [] = ""
