@@ -115,7 +115,7 @@ main = do
     (argsbeforecmd, argsaftercmd') = break (==rawcmd) args
     argsaftercmd         = drop 1 argsaftercmd'
     dbgIO :: Show a => String -> a -> IO ()
-    dbgIO = tracePrettyAtIO 2
+    dbgIO = ptraceAtIO 2
 
   dbgIO "running" prognameandversion
   dbgIO "raw args" args
@@ -169,14 +169,17 @@ main = do
       | isBadCommand             = badCommandError
 
       -- builtin commands
-      | Just (cmdmode, cmdaction) <- findCommand cmd = do 
-        if cmd=="add" -- add command does extra work before reading journal
-        then (do
-          journalFilePathFromOpts opts >>= (ensureJournalFileExists . head) 
-          withJournalDo opts cmdaction)
-          `orShowHelp` cmdmode
-        else
-          withJournalDo opts cmdaction `orShowHelp` cmdmode
+      | Just (cmdmode, cmdaction) <- findCommand cmd =
+        (case cmd of
+          "test" -> -- should not read the journal
+            cmdaction opts (error "journal-less command tried to use the journal")
+          "add" ->  -- should create the journal if missing
+            (ensureJournalFileExists =<< (head <$> journalFilePathFromOpts opts)) >>
+            withJournalDo opts cmdaction
+          _ ->      -- all other commands: read the journal or fail if missing
+            withJournalDo opts cmdaction
+        )
+        `orShowHelp` cmdmode
 
       -- addon commands
       | isExternalCommand = do
@@ -225,16 +228,21 @@ moveFlagsAfterCommand args = moveArgs $ ensureDebugHasArg args
        (bs,"--debug":[])                                   -> bs++"--debug=1":[]
        _                                                   -> as
 
-    -- -h ..., --version ...
-    moveArgs (f:a:as)   | isMovableNoArgFlag f                   = (moveArgs $ a:as) ++ [f]
-    -- -f FILE ..., --alias ALIAS ...
-    moveArgs (f:v:a:as) | isMovableReqArgFlag f, isValue v       = (moveArgs $ a:as) ++ [f,v]
-    -- -fFILE ..., --alias=ALIAS ...
-    moveArgs (fv:a:as)  | isMovableReqArgFlagAndValue fv         = (moveArgs $ a:as) ++ [fv]
-    -- -f(missing arg)
-    moveArgs (f:a:as)   | isMovableReqArgFlag f, not (isValue a) = (moveArgs $ a:as) ++ [f]
-    -- anything else
-    moveArgs as = as
+    moveArgs args = insertFlagsAfterCommand $ moveArgs' (args, [])
+      where
+        -- -h ..., --version ...
+        moveArgs' ((f:a:as), flags)   | isMovableNoArgFlag f                   = moveArgs' (a:as, flags ++ [f])
+        -- -f FILE ..., --alias ALIAS ...
+        moveArgs' ((f:v:a:as), flags) | isMovableReqArgFlag f, isValue v       = moveArgs' (a:as, flags ++ [f,v])
+        -- -fFILE ..., --alias=ALIAS ...
+        moveArgs' ((fv:a:as), flags)  | isMovableReqArgFlagAndValue fv         = moveArgs' (a:as, flags ++ [fv])
+        -- -f(missing arg)
+        moveArgs' ((f:a:as), flags)   | isMovableReqArgFlag f, not (isValue a) = moveArgs' (a:as, flags ++ [f])
+        -- anything else
+        moveArgs' (as, flags) = (as, flags)
+
+        insertFlagsAfterCommand ([],           flags) = flags
+        insertFlagsAfterCommand (command:args, flags) = [command] ++ flags ++ args
 
 isMovableNoArgFlag a  = "-" `isPrefixOf` a && dropWhile (=='-') a `elem` noargflagstomove
 
