@@ -1,4 +1,5 @@
-{-# LANGUAGE ScopedTypeVariables, CPP #-}
+{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE NoOverloadedStrings #-} -- prevent trouble if turned on in ghci
 {-|
 
 Utilities for top-level modules and ghci. See also Hledger.Read and
@@ -13,7 +14,6 @@ module Hledger.Cli.Utils
      journalTransform,
      journalApplyValue,
      journalAddForecast,
-     generateAutomaticPostings,
      journalReload,
      journalReloadIfChanged,
      journalFileIsNewer,
@@ -25,7 +25,6 @@ module Hledger.Cli.Utils
      readFileStrictly,
      pivotByOpts,
      anonymiseByOpts,
-     Test(TestList),
     )
 where
 import Control.Exception as C
@@ -47,7 +46,6 @@ import System.FilePath ((</>), splitFileName, takeDirectory)
 import System.Info (os)
 import System.Process (readProcessWithExitCode)
 import System.Time (ClockTime, getClockTime, diffClockTimes, TimeDiff(TimeDiff))
-import Test.HUnit
 import Text.Printf
 import Text.Regex.TDFA ((=~))
 
@@ -108,6 +106,7 @@ anonymise j
       pAnons p = p { paccount = T.intercalate (T.pack ":") . map anon . T.splitOn (T.pack ":") . paccount $ p
                    , pcomment = T.empty
                    , ptransaction = fmap tAnons . ptransaction $ p
+                   , porigin = pAnons <$> porigin p
                    }
       tAnons txn = txn { tpostings = map pAnons . tpostings $ txn
                        , tdescription = anon . tdescription $ txn
